@@ -6,9 +6,12 @@ from ListSessions import Ui_ListSessions
 from ViewSessionExt import ViewSessionExt
 from WindowFilterOptionsExt import WindowFilterOptionsExt
 from MyItemDelegate import MyItemDelegate
-import DialogDBStatistics
+#import DialogDBStatistics
+import DialogDBStatisticsExt
 import StatistData
 
+import DialogStatSessions
+
 from mydb import MyDB
 import myconfig
 
@@ -188,6 +191,9 @@ class ListSessionsExt( QtGui.QMainWindow ):
 		plugin = MyItemDelegate( self, 1 )
 		self.ui.listWidgetSessions.setItemDelegate( plugin )
 		
+		QtCore.QObject.connect( QtGui.QApplication.desktop(), QtCore.SIGNAL("resized(int)"), self.orientationChanged )
+		self.orientationChanged()
+		
 
 #	def keyReleaseEvent(self, ev):
 #		if ev.key() == 65:
@@ -435,9 +441,10 @@ class ListSessionsExt( QtGui.QMainWindow ):
 
 	#--- диалог со статистикой БД ---
 	def DlgDBStatistics(self):
-		self.dlgDBStat = QtGui.QDialog()
-		self.ui_dlgDBStat = DialogDBStatistics.Ui_DialogDBStat()
-		self.ui_dlgDBStat.setupUi( self.dlgDBStat )
+		self.dlgDBStat = QtGui.QDialog( self )
+		#self.ui_dlgDBStat = DialogDBStatistics.Ui_DialogDBStat()
+		self.ui_dlgDBStat = DialogDBStatisticsExt.DialogDBStatisticsExt( self.dlgDBStat )
+		#self.ui_dlgDBStat.setupUi( self.dlgDBStat )
 
 		self.ui_dlgDBStat.pB_Done.clicked.connect( self.dlgDBStat.hide )
 
@@ -498,16 +505,56 @@ class ListSessionsExt( QtGui.QMainWindow ):
 			return
 		
 		summ_b = rx_summ + tx_summ
-		txt1 = QtGui.QApplication.translate("ListSessionsExt", "Sessions:", None, QtGui.QApplication.UnicodeUTF8)
-		txt2 = QtGui.QApplication.translate("ListSessionsExt", "RX bytes:", None, QtGui.QApplication.UnicodeUTF8)
-		txt3 = QtGui.QApplication.translate("ListSessionsExt", "TX bytes:", None, QtGui.QApplication.UnicodeUTF8)
-		txt4 = QtGui.QApplication.translate("ListSessionsExt", "Full traffic:", None, QtGui.QApplication.UnicodeUTF8)
-		text  = "\t\t\t%s \t\t %s\n"%( txt1, countSelectedSession )
-		text += "\t\t\t%s \t\t %s\n"%( txt2, StatistData.strHumanBytes( rx_summ ) )
-		text += "\t\t\t%s \t\t %s\n"%( txt3, StatistData.strHumanBytes( tx_summ ) )
-		text += "\t\t\t%s \t\t %s"%( txt4, StatistData.strHumanBytes( summ_b ))
-		self.noti.notify_m("%s"%text)
+		self.dlgStat = QtGui.QDialog( self )
+		self.ui_dlgStat = DialogStatSessions.Ui_DialogStatSessions()
+		self.ui_dlgStat.setupUi( self.dlgStat )
+		self.ui_dlgStat.lbl_session_val.setText( "%s"%countSelectedSession )
+		self.ui_dlgStat.lbl_sent_val.setText( "%s"%StatistData.strHumanBytes( rx_summ ) )
+		self.ui_dlgStat.lbl_recv_val.setText( "%s"%StatistData.strHumanBytes( tx_summ ) )
+		self.ui_dlgStat.lbl_full_val.setText( "%s"%StatistData.strHumanBytes( summ_b ) )
+		self.dlgStat.show()
 	
 
+	def orientationChanged( self ):
+		screenGeometry = QtGui.QApplication.desktop().screenGeometry()
+			
+		self.ui.gridLayout.removeWidget( self.ui.listWidgetSessions )
+		self.ui.gridLayout.removeWidget( self.ui.pBFilter )
+		self.ui.gridLayout.removeWidget( self.ui.pBVSelectedAll )
+		self.ui.gridLayout.removeWidget( self.ui.pBDeleteItem )
+		self.ui.gridLayout.removeWidget( self.ui.pBViewItem )
+
+		if screenGeometry.width() > screenGeometry.height():
+			# landscape
+			self.w_refresh.setGeometry(QtCore.QRect(670, 10, 130, 50))
+
+			self.ui.listWidgetSessions.setMinimumSize(QtCore.QSize(780, 320))
+			self.ui.gridLayout.addWidget( self.ui.listWidgetSessions, 0, 0, 1, 4 )
+
+			self.ui.pBFilter.setMinimumSize(QtCore.QSize(190,70))
+			self.ui.pBVSelectedAll.setMinimumSize(QtCore.QSize(190,70))
+			self.ui.pBDeleteItem.setMinimumSize(QtCore.QSize(190,70))
+			self.ui.pBViewItem.setMinimumSize(QtCore.QSize(190,70))
+
+			self.ui.gridLayout.addWidget( self.ui.pBFilter, 1, 0 )
+			self.ui.gridLayout.addWidget( self.ui.pBVSelectedAll, 1, 1 )
+			self.ui.gridLayout.addWidget( self.ui.pBDeleteItem, 1, 2 )
+			self.ui.gridLayout.addWidget( self.ui.pBViewItem, 1, 3 )
+		else:
+			#portait
+			self.w_refresh.setGeometry(QtCore.QRect(350, 10, 130, 50))
+
+			self.ui.listWidgetSessions.setMinimumSize(QtCore.QSize(450, 550))
+			self.ui.gridLayout.addWidget( self.ui.listWidgetSessions, 0, 0, 1, 2 )
+
+			self.ui.pBFilter.setMinimumSize(QtCore.QSize(220,80))
+			self.ui.pBVSelectedAll.setMinimumSize(QtCore.QSize(220,80))
+			self.ui.pBDeleteItem.setMinimumSize(QtCore.QSize(220,80))
+			self.ui.pBViewItem.setMinimumSize(QtCore.QSize(220,80))
+
+			self.ui.gridLayout.addWidget( self.ui.pBFilter, 1, 0 )
+			self.ui.gridLayout.addWidget( self.ui.pBVSelectedAll, 1, 1 )
+			self.ui.gridLayout.addWidget( self.ui.pBDeleteItem, 2, 0 )
+			self.ui.gridLayout.addWidget( self.ui.pBViewItem, 2, 1 )
 
 
