@@ -151,9 +151,11 @@ class WinAboutExt( QtGui.QMainWindow ):
 		str  = "<html>"
 		str += "<div style='font-size: 14pt;'>"
 		str += "<p>%s</p>"%txt1
-		str += "%s<br/>"%txt2
-		str += "%s<br/>"%txt4
-		str += "%s<br/>"%txt3
+		str += "<ul>"
+		str += "<li>%s<br/></li>"%txt2
+		str += "<li>%s<br/></li>"%txt4
+		str += "<li>%s<br/></li>"%txt3
+		str += "</ul>"
 		str += "</div>"
 		str += "</html>"
 		self.tE_p2.setHtml( str )
