@@ -6,7 +6,7 @@ import WindowFilterOptions
 import DateWindowExt
 from gettraff import GetTraff
 import myconfig
-from StatistData import pixmapIface_str
+from StatistData import pixmapIface_str, checkOrientation
 
 class WindowFilterOptionsExt( QtGui.QMainWindow ):
 	def __init__(self, parent, parentUi, qset ):
@@ -77,6 +77,9 @@ class WindowFilterOptionsExt( QtGui.QMainWindow ):
 		eT = self.qset.filterGetStopTime()
 		if eT != None:
 			self.ui.dTEEnd.setDateTime( QtCore.QDateTime.fromString( eT, "yyyy-MM-dd HH:mm:ss") )
+		
+		QtCore.QObject.connect( QtGui.QApplication.desktop(), QtCore.SIGNAL("resized(int)"), self.orientationChanged )
+		self.orientationChanged()
 
 
 
@@ -153,3 +156,51 @@ class WindowFilterOptionsExt( QtGui.QMainWindow ):
 	def winCalEndDate(self):
 		self.wDate = DateWindowExt.DateWindowExt( self, self.ui.dTEEnd )
 		self.wDate.show()
+	
+	
+	def orientationChanged( self ):
+			
+		self.ui.gridLayout.removeWidget( self.ui.cBStart )
+		self.ui.gridLayout.removeWidget( self.ui.cBEnd )
+		self.ui.gridLayout.removeWidget( self.ui.dTEStart )
+		self.ui.gridLayout.removeWidget( self.ui.dTEEnd )
+		self.ui.gridLayout.removeWidget( self.ui.pBCalStart )
+		self.ui.gridLayout.removeWidget( self.ui.pBCalEnd )
+		self.ui.gridLayout.removeWidget( self.ui.lWIface )
+		#self.ui.gridLayout.removeWidget( self.ui.pBAccept )
+		#self.ui.gridLayout.removeWidget( self.ui.pBCancel )
+		self.ui.gridLayout.removeItem( self.ui.horizontalLayout )
+
+		o = checkOrientation()
+		if o == "L":
+			# landscape
+			self.ui.gridLayout.addWidget( self.ui.lWIface, 0, 2, 4, 1 )
+
+			self.ui.pBCalStart.setMinimumSize(QtCore.QSize(100,90))
+
+			self.ui.gridLayout.addWidget( self.ui.cBStart, 0, 0, 1, 2 )
+			self.ui.gridLayout.addWidget( self.ui.dTEStart, 1, 0 )
+			self.ui.gridLayout.addWidget( self.ui.pBCalStart, 1, 1 )
+
+			self.ui.gridLayout.addWidget( self.ui.cBEnd, 2, 0, 1, 2 )
+			self.ui.gridLayout.addWidget( self.ui.dTEEnd, 3, 0 )
+			self.ui.gridLayout.addWidget( self.ui.pBCalEnd, 3, 1 )
+
+			#self.ui.gridLayout.addWidget( self.ui.pBCancel, 4, 0  )
+			#self.ui.gridLayout.addWidget( self.ui.pBAccept, 4, 1, 1, 2  )
+			self.ui.gridLayout.addItem( self.ui.horizontalLayout, 4, 0, 1, 4 )
+		else:
+			#portait
+			self.ui.gridLayout.addWidget( self.ui.lWIface, 0, 0, 1, 4 )
+
+			self.ui.gridLayout.addWidget( self.ui.cBStart, 1, 0, 1, 4 )
+			self.ui.gridLayout.addWidget( self.ui.dTEStart, 2, 0, 1, 3 )
+			self.ui.gridLayout.addWidget( self.ui.pBCalStart, 2, 3 )
+
+			self.ui.gridLayout.addWidget( self.ui.cBEnd, 3, 0, 1, 4 )
+			self.ui.gridLayout.addWidget( self.ui.dTEEnd, 4, 0, 1, 3 )
+			self.ui.gridLayout.addWidget( self.ui.pBCalEnd, 4, 3 )
+			
+			#self.ui.gridLayout.addWidget( self.ui.pBCancel, 5, 0, 1, 4  )
+			#self.ui.gridLayout.addWidget( self.ui.pBAccept, 6, 0, 1, 4  )
+			self.ui.gridLayout.addItem( self.ui.horizontalLayout, 5, 0, 1, 4 )
