@@ -11,6 +11,7 @@ from sys import argv, exit
 from pysrc import MainWindowExt
 from pysrc import myconfig
 from pysrc import pic_rc
+from pysrc import QNMSettings
 
 from dbus.mainloop.glib import DBusGMainLoop
 DBusGMainLoop(set_as_default=True)
@@ -23,17 +24,25 @@ if __name__ == "__main__":
 	#splash = QtGui.QSplashScreen(pxm)
 	#splash.show()
 	#app.processEvents()
+		
+	qset = QNMSettings.QNMSettings( myconfig.file_setting, app )
 
 	trans = QtCore.QTranslator()
-
 	lcl = QtCore.QLocale()
-	
-	if lcl.language() == QtCore.QLocale.Russian:
+	L = qset.language() # this parameter is set to pysrc/OptionsWindowExt.py:63:110:189
+
+	if L == "0":
+		if lcl.language() == QtCore.QLocale.Russian:
+			trans.load( myconfig.i18n_rus )
+			app.installTranslator( trans )
+	elif L == "en":
+		pass
+	elif L == "ru":
 		trans.load( myconfig.i18n_rus )
 		app.installTranslator( trans )
 	
 	#ui = MainWindowExt.MainWindowExt( splash )
-	ui = MainWindowExt.MainWindowExt()
+	ui = MainWindowExt.MainWindowExt( qset )
 
 	ui.show()
 
